/*
	kclose		Close the serial port for K-Team robots
	
	The calling syntax is:
		
		kclose(ref)
	
	Arguments:
	
		ref:		the reference to the serial port obtained with kopen

	Under Windows, compile by typing in Matlab's command line

		mex -output kclose KClose.c KhepComWin.c
	
	Copyright 1998, Yves Piguet
	All Righs Reserved
*/

//#include "CodeWarrior.MEX.prefix"

#include "mex.h"

#include "KhepCom.h"

/* Input Arguments */

#define	PORTREF_IN	prhs[0]

// Main Function

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
	short port;
	long rate;
	double timeout;
	KPortRef portRef;
	double *ref;	// same, in the input argument
	int err;
	
	/* Checks for proper number of arguments */
	
	if (nrhs != 1 || nlhs > 0)
		mexErrMsgTxt("KCLOSE syntax: kclose(ref)");
	
	/* Gets the parameters */
	
	if(!mxIsDouble(PORTREF_IN) || mxIsComplex(PORTREF_IN) ||
								mxGetM(PORTREF_IN) != 1 || mxGetN(PORTREF_IN) != 4) 
		mexErrMsgTxt("KCLOSE arg. must be a row vector of four numbers");
	ref = mxGetPr(PORTREF_IN);
	portRef.priv[0] = ref[0];
	portRef.priv[1] = ref[1];
	portRef.priv[2] = ref[2];
	portRef.priv[3] = ref[3];
	
	KCloseSerial(&portRef);
}
