/*
 *	ksendcommand.c
 *
 *	osax for communication with K-Team devices via serial port
 *	cf. tn1164.html
 *
 *	Copyright 1999, Yves Piguet
 */

#include "KhepCom.h"
#include <AppleEvents.h>
#include <Errors.h>

#define theAEEventClass 'K-Tm'
#define theAEEventID 'scmd'

OSErr CFMInit();
void CFMTerminate();

static AEEventHandlerUPP ksendcmdUpp = 0;

static pascal OSErr MyHandleKSendCmd(AppleEvent *evt, AppleEvent *reply, long refCon)
{
	DescType retType, sourceAttr;
	Size size;
	AEDesc cmdDesc;
	char *answer;
	long answerLength;
	OSErr err;
	
	err = AEGetAttributePtr(evt, keyEventSourceAttr, typeType,
								&retType, &sourceAttr, sizeof(sourceAttr), &size);
	if (err != noErr || sourceAttr == kAERemoteProcess )
		return errAEEventNotHandled;
	
	err = AEGetParamDesc(evt, keyDirectObject, typeChar, &cmdDesc);
	if (err != noErr)
		return err;
	HLock(cmdDesc.dataHandle);
	answer = (char *)NewPtr(8192);
	if (answer)
	{
		if (KOpenSendClose(1, 19200, 1000,
							(char *)*cmdDesc.dataHandle, GetHandleSize(cmdDesc.dataHandle),
							&answer, 8192, &answerLength,
							1,
							0) == kKhepNoErr)
			err = AEPutParamPtr(reply, keyDirectObject, typeChar, answer, answerLength);
		else
			err = -1;
		DisposePtr(answer);
	}
	else
		err = MemError();
	(void)AEDisposeDesc(&cmdDesc);
	
	return err;
}

OSErr CFMInit()
{
	OSErr err;
	
	DebugStr("\pCFMInit");
	
	ksendcmdUpp = NewAEEventHandlerProc(MyHandleKSendCmd);
	err = AEInstallEventHandler(theAEEventClass, theAEEventID, ksendcmdUpp, 0, 1);
	
	return err;
}

void CFMTerminate()
{
	DebugStr("\pCFMTerminate");
	
	(void)AERemoveEventHandler(theAEEventClass, theAEEventID, ksendcmdUpp, 1);
}
